@@ -1,6 +1,7 @@
 from graphene import List, ObjectType
 
 from .sql.types import DjangoDebugSQL
+from .exception.types import DjangoDebugException
 
 
 class DjangoDebug(ObjectType):
@@ -8,3 +9,6 @@ class DjangoDebug(ObjectType):
         description = "Debugging information for the current query."
 
     sql = List(DjangoDebugSQL, description="Executed SQL queries for this API query.")
+    exceptions = List(
+        DjangoDebugException, description="Raise exceptions for this API query."
+    )
