@@ -5,18 +5,18 @@ import pytest
 from django.db.models import TextField, Value
 from django.db.models.functions import Concat
 
-from graphene import Argument, Boolean, Field, Float, ObjectType, Schema, String
+from graphene import Argument, Boolean, Decimal, Field, ObjectType, Schema, String
 from graphene.relay import Node
 from graphene_django import DjangoObjectType
 from graphene_django.forms import GlobalIDFormField, GlobalIDMultipleChoiceField
-from graphene_django.tests.models import Article, Pet, Reporter
+from graphene_django.tests.models import Article, Person, Pet, Reporter
 from graphene_django.utils import DJANGO_FILTER_INSTALLED
 
 pytestmark = []
 
 if DJANGO_FILTER_INSTALLED:
     import django_filters
-    from django_filters import FilterSet, NumberFilter
+    from django_filters import FilterSet, NumberFilter, OrderingFilter
 
     from graphene_django.filter import (
         GlobalIDFilter,
@@ -41,17 +41,20 @@ if DJANGO_FILTER_INSTALLED:
         class Meta:
             model = Article
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ("headline",)
 
     class ReporterNode(DjangoObjectType):
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
 
     class PetNode(DjangoObjectType):
         class Meta:
             model = Pet
             interfaces = (Node,)
+            fields = "__all__"
 
 
 def get_args(field):
@@ -64,7 +67,7 @@ def assert_arguments(field, *arguments):
     actual = [name for name in args if name not in ignore and not name.startswith("_")]
     assert set(arguments) == set(
         actual
-    ), "Expected arguments ({}) did not match actual ({})".format(arguments, actual)
+    ), f"Expected arguments ({arguments}) did not match actual ({actual})"
 
 
 def assert_orderable(field):
@@ -87,6 +90,7 @@ def test_filter_explicit_filterset_arguments():
         "pub_date__gt",
         "pub_date__lt",
         "reporter",
+        "reporter__in",
     )
 
 
@@ -137,7 +141,7 @@ def test_filter_shortcut_filterset_context():
 
         @property
         def qs(self):
-            qs = super(ArticleContextFilter, self).qs
+            qs = super().qs
             return qs.filter(reporter=self.request.reporter)
 
     class Query(ObjectType):
@@ -162,7 +166,7 @@ def test_filter_shortcut_filterset_context():
         editor=r2,
     )
 
-    class context(object):
+    class context:
         reporter = r2
 
     query = """
@@ -189,6 +193,7 @@ def test_filter_filterset_information_on_meta():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["first_name", "articles"]
 
     field = DjangoFilterConnectionField(ReporterFilterNode)
@@ -201,12 +206,14 @@ def test_filter_filterset_information_on_meta_related():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["first_name", "articles"]
 
     class ArticleFilterNode(DjangoObjectType):
         class Meta:
             model = Article
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["headline", "reporter"]
 
     class Query(ObjectType):
@@ -233,6 +240,7 @@ def test_filter_filterset_class_filter_fields_exception():
             class Meta:
                 model = Reporter
                 interfaces = (Node,)
+                fields = "__all__"
                 filterset_class = ReporterFilter
                 filter_fields = ["first_name", "articles"]
 
@@ -247,6 +255,7 @@ def test_filter_filterset_class_information_on_meta():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filterset_class = ReporterFilter
 
     field = DjangoFilterConnectionField(ReporterFilterNode)
@@ -269,12 +278,14 @@ def test_filter_filterset_class_information_on_meta_related():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filterset_class = ReporterFilter
 
     class ArticleFilterNode(DjangoObjectType):
         class Meta:
             model = Article
             interfaces = (Node,)
+            fields = "__all__"
             filterset_class = ArticleFilter
 
     class Query(ObjectType):
@@ -294,12 +305,14 @@ def test_filter_filterset_related_results():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["first_name", "articles"]
 
     class ArticleFilterNode(DjangoObjectType):
         class Meta:
             interfaces = (Node,)
             model = Article
+            fields = "__all__"
             filter_fields = ["headline", "reporter"]
 
     class Query(ObjectType):
@@ -388,7 +401,7 @@ def test_filterset_descriptions():
     field = DjangoFilterConnectionField(ArticleNode, filterset_class=ArticleIdFilter)
     max_time = field.args["max_time"]
     assert isinstance(max_time, Argument)
-    assert max_time.type == Float
+    assert max_time.type == Decimal
     assert max_time.description == "The maximum time"
 
 
@@ -405,12 +418,14 @@ def test_global_id_field_relation_with_filter():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["first_name", "articles"]
 
     class ArticleFilterNode(DjangoObjectType):
         class Meta:
             model = Article
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["headline", "reporter"]
 
     class Query(ObjectType):
@@ -460,12 +475,14 @@ def test_global_id_field_relation_with_filter_not_valid_id():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["first_name", "articles"]
 
     class ArticleFilterNode(DjangoObjectType):
         class Meta:
             model = Article
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ["headline", "reporter"]
 
     class Query(ObjectType):
@@ -559,6 +576,7 @@ def test_filter_filterset_related_results_with_filter():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = {"first_name": ["icontains"]}
 
     class Query(ObjectType):
@@ -604,6 +622,7 @@ def test_recursive_filter_connection():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
 
     class Query(ObjectType):
         all_reporters = DjangoFilterConnectionField(ReporterFilterNode)
@@ -629,11 +648,13 @@ def test_should_query_filter_node_limit():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
 
     class ArticleType(DjangoObjectType):
         class Meta:
             model = Article
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ("lang",)
 
     class Query(ObjectType):
@@ -676,7 +697,7 @@ def test_should_query_filter_node_limit():
                     node {
                         id
                         firstName
-                        articles(lang: "es") {
+                        articles(lang: ES) {
                             edges {
                                 node {
                                     id
@@ -718,6 +739,7 @@ def test_order_by():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
 
     class Query(ObjectType):
         all_reporters = DjangoFilterConnectionField(
@@ -785,6 +807,7 @@ def test_order_by_is_perserved():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ()
 
     class Query(ObjectType):
@@ -851,6 +874,7 @@ def test_annotation_is_preserved():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ()
 
     class Query(ObjectType):
@@ -893,6 +917,7 @@ def test_annotation_with_only():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ()
 
     class Query(ObjectType):
@@ -933,6 +958,7 @@ def test_node_get_queryset_is_called():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
             filter_fields = ()
 
         @classmethod
@@ -981,40 +1007,56 @@ def test_integer_field_filter_type():
 
     assert str(schema) == dedent(
         """\
-        schema {
-          query: Query
+        type Query {
+          pets(offset: Int, before: String, after: String, first: Int, last: Int, age: Int): PetTypeConnection
         }
 
-        interface Node {
-          id: ID!
+        type PetTypeConnection {
+          \"""Pagination data for this connection.\"""
+          pageInfo: PageInfo!
+
+          \"""Contains the nodes in this connection.\"""
+          edges: [PetTypeEdge]!
         }
 
+        \"""
+        The Relay compliant `PageInfo` type, containing data necessary to paginate this connection.
+        \"""
         type PageInfo {
+          \"""When paginating forwards, are there more items?\"""
           hasNextPage: Boolean!
+
+          \"""When paginating backwards, are there more items?\"""
           hasPreviousPage: Boolean!
+
+          \"""When paginating backwards, the cursor to continue.\"""
           startCursor: String
+
+          \"""When paginating forwards, the cursor to continue.\"""
           endCursor: String
         }
 
+        \"""A Relay edge containing a `PetType` and its cursor.\"""
+        type PetTypeEdge {
+          \"""The item at the end of the edge\"""
+          node: PetType
+
+          \"""A cursor for use in pagination\"""
+          cursor: String!
+        }
+
         type PetType implements Node {
           age: Int!
+
+          \"""The ID of the object\"""
           id: ID!
         }
 
-        type PetTypeConnection {
-          pageInfo: PageInfo!
-          edges: [PetTypeEdge]!
-        }
-
-        type PetTypeEdge {
-          node: PetType
-          cursor: String!
-        }
-
-        type Query {
-          pets(offset: Int, before: String, after: String, first: Int, last: Int, age: Int): PetTypeConnection
-        }
-    """
+        \"""An object with an ID\"""
+        interface Node {
+          \"""The ID of the object\"""
+          id: ID!
+        }"""
     )
 
 
@@ -1033,40 +1075,56 @@ def test_other_filter_types():
 
     assert str(schema) == dedent(
         """\
-        schema {
-          query: Query
+        type Query {
+          pets(offset: Int, before: String, after: String, first: Int, last: Int, age: Int, age_Isnull: Boolean, age_Lt: Int): PetTypeConnection
         }
 
-        interface Node {
-          id: ID!
+        type PetTypeConnection {
+          \"""Pagination data for this connection.\"""
+          pageInfo: PageInfo!
+
+          \"""Contains the nodes in this connection.\"""
+          edges: [PetTypeEdge]!
         }
 
+        \"""
+        The Relay compliant `PageInfo` type, containing data necessary to paginate this connection.
+        \"""
         type PageInfo {
+          \"""When paginating forwards, are there more items?\"""
           hasNextPage: Boolean!
+
+          \"""When paginating backwards, are there more items?\"""
           hasPreviousPage: Boolean!
+
+          \"""When paginating backwards, the cursor to continue.\"""
           startCursor: String
+
+          \"""When paginating forwards, the cursor to continue.\"""
           endCursor: String
         }
 
+        \"""A Relay edge containing a `PetType` and its cursor.\"""
+        type PetTypeEdge {
+          \"""The item at the end of the edge\"""
+          node: PetType
+
+          \"""A cursor for use in pagination\"""
+          cursor: String!
+        }
+
         type PetType implements Node {
           age: Int!
+
+          \"""The ID of the object\"""
           id: ID!
         }
 
-        type PetTypeConnection {
-          pageInfo: PageInfo!
-          edges: [PetTypeEdge]!
-        }
-
-        type PetTypeEdge {
-          node: PetType
-          cursor: String!
-        }
-
-        type Query {
-          pets(offset: Int, before: String, after: String, first: Int, last: Int, age: Int, age_Isnull: Boolean, age_Lt: Int): PetTypeConnection
-        }
-    """
+        \"""An object with an ID\"""
+        interface Node {
+          \"""The ID of the object\"""
+          id: ID!
+        }"""
     )
 
 
@@ -1085,7 +1143,7 @@ def test_filter_filterset_based_on_mixin():
 
             return filters
 
-        def filter_email_in(cls, queryset, name, value):
+        def filter_email_in(self, queryset, name, value):
             return queryset.filter(**{name: [value]})
 
     class NewArticleFilter(ArticleFilterMixin, ArticleFilter):
@@ -1095,6 +1153,7 @@ def test_filter_filterset_based_on_mixin():
         class Meta:
             model = Reporter
             interfaces = (Node,)
+            fields = "__all__"
 
     class NewArticleFilterNode(DjangoObjectType):
         viewer = Field(NewReporterNode)
@@ -1102,6 +1161,7 @@ def test_filter_filterset_based_on_mixin():
         class Meta:
             model = Article
             interfaces = (Node,)
+            fields = "__all__"
             filterset_class = NewArticleFilter
 
         def resolve_viewer(self, info):
@@ -1136,10 +1196,9 @@ def test_filter_filterset_based_on_mixin():
 
     schema = Schema(query=Query)
 
-    query = (
-        """
-        query NodeFilteringQuery {
-            allArticles(viewer_Email_In: "%s") {
+    query = """
+        query NodeFilteringQuery ($email: String!) {
+            allArticles(viewer_Email_In: $email) {
                 edges {
                     node {
                         headline
@@ -1151,8 +1210,6 @@ def test_filter_filterset_based_on_mixin():
             }
         }
     """
-        % reporter_1.email
-    )
 
     expected = {
         "allArticles": {
@@ -1167,7 +1224,81 @@ def test_filter_filterset_based_on_mixin():
         }
     }
 
-    result = schema.execute(query)
+    result = schema.execute(query, variable_values={"email": reporter_1.email})
 
     assert not result.errors
     assert result.data == expected
+
+
+def test_filter_string_contains():
+    class PersonType(DjangoObjectType):
+        class Meta:
+            model = Person
+            interfaces = (Node,)
+            fields = "__all__"
+            filter_fields = {"name": ["exact", "in", "contains", "icontains"]}
+
+    class Query(ObjectType):
+        people = DjangoFilterConnectionField(PersonType)
+
+    schema = Schema(query=Query)
+
+    Person.objects.bulk_create(
+        [
+            Person(name="Jack"),
+            Person(name="Joe"),
+            Person(name="Jane"),
+            Person(name="Peter"),
+            Person(name="Bob"),
+        ]
+    )
+    query = """query nameContain($filter: String) {
+        people(name_Contains: $filter) {
+            edges {
+                node {
+                    name
+                }
+            }
+        }
+    }"""
+
+    result = schema.execute(query, variables={"filter": "Ja"})
+    assert not result.errors
+    assert result.data == {
+        "people": {
+            "edges": [
+                {"node": {"name": "Jack"}},
+                {"node": {"name": "Jane"}},
+            ]
+        }
+    }
+
+    result = schema.execute(query, variables={"filter": "o"})
+    assert not result.errors
+    assert result.data == {
+        "people": {
+            "edges": [
+                {"node": {"name": "Joe"}},
+                {"node": {"name": "Bob"}},
+            ]
+        }
+    }
+
+
+def test_only_custom_filters():
+    class ReporterFilter(FilterSet):
+        class Meta:
+            model = Reporter
+            fields = []
+
+        some_filter = OrderingFilter(fields=("name",))
+
+    class ReporterFilterNode(DjangoObjectType):
+        class Meta:
+            model = Reporter
+            interfaces = (Node,)
+            fields = "__all__"
+            filterset_class = ReporterFilter
+
+    field = DjangoFilterConnectionField(ReporterFilterNode)
+    assert_arguments(field, "some_filter")
